@@ -5,7 +5,16 @@ OC.L10N.register(
     "Personal" : "Асабістыя",
     "Mail" : "Пошта",
     "You are reaching your mailbox quota limit for {account_email}" : "Вы дасягаеце ліміту квоты вашай паштовай скрынкі для {account_email} ",
+    "Drafts are saved in:" : "Чарнавікі захоўваюцца ў:",
+    "Sent messages are saved in:" : "Адпраўленыя паведамленні захоўваюцца ў:",
+    "Deleted messages are moved in:" : "Выдаленыя паведамленні перамяшчаюцца ў:",
+    "Archived messages are moved in:" : "Архіваваныя паведамленні перамяшчаюцца ў:",
+    "Snoozed messages are moved in:" : "Адкладзеныя паведамленні перамяшчаюцца ў:",
+    "Sign in with Google" : "Увайсці з дапамогай Google",
+    "Sign in with Microsoft" : "Увайсці з дапамогай Microsoft",
     "Save" : "Захаваць",
+    "Loading account" : "Загрузка ўліковага запісу",
+    "Account updated" : "Уліковы запіс абноўлены",
     "Name" : "Назва",
     "name@example.org" : "name@example.org",
     "Password" : "Пароль",
@@ -53,6 +62,7 @@ OC.L10N.register(
     "Bcc" : "Bcc",
     "Subject" : "Тэма",
     "Subject …" : "Тэма …",
+    "Write message …" : "Напішыце паведамленне …",
     "Saving draft …" : "Захаванне чарнавіка …",
     "Error saving draft" : "Памылка пры захаванні чарнавіка",
     "Draft saved" : "Чарнавік захаваны",
@@ -141,11 +151,15 @@ OC.L10N.register(
     "Could not discard message" : "Не ўдалося адхіліць паведамленне",
     "Retry" : "Паўтарыць спробу",
     "Message" : "Паведамленне",
+    "New Contact" : "Новы кантакт",
     "Copy to clipboard" : "Капіяваць у буфер абмену",
     "Add" : "Дадаць",
     "Clear" : "Ачысціць",
+    "Search in folder" : "Пошук у папцы",
     "Close" : "Закрыць",
     "Date" : "Дата",
+    "Pick a start date" : "Выберыце дату пачатку",
+    "Pick an end date" : "Выберыце дату заканчэння",
     "Tags" : "Тэгі",
     "Last 7 days" : "Апошнія 7 дзён",
     "Custom" : "Карыстальніцкі",
@@ -163,6 +177,7 @@ OC.L10N.register(
     "Translating" : "Пераклад",
     "Copy translated text" : "Скапіяваць перакладзены тэкст",
     "Untitled event" : "Падзея без назвы",
+    "(organizer)" : "(арганізатар)",
     "Train" : "Цягнік",
     "Move into folder" : "Перамясціць у папку",
     "Stop" : "Спыніць",
