@@ -425,9 +425,12 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} от {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
     "Train" : "Влак",
+    "Stop" : "Спиране /на/",
     "Recipient" : "Получател",
+    "Help" : "Помощ",
     "contains" : "съдържа",
     "matches" : "съвпадения",
+    "Actions" : "Действия",
     "Priority" : "Приоритет",
     "Tag" : "Етикет",
     "delete" : "изтриване",
@@ -564,10 +567,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочване",
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
-    "Continue to %s" : "Продължи към %s",
-    "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
-    "Install Mailvelope browser extension" : "Инсталирайте разширението за браузър Mailvelope",
-    "Flag" : "Знаме",
-    "Operator" : "Оператор"
+    "Continue to %s" : "Продължи към %s"
 },
 "nplurals=2; plural=(n != 1);");
