@@ -233,14 +233,14 @@ OC.L10N.register(
     "Choose" : "Vali",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Manuse maht ületab lubatud suuruse {size}. Selle asemel palun jaga seda faili lingiga.","Manuste maht ületab lubatud suuruse {size}. Selle asemel palun jaga neid faile lingiga."],
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
-    "Choose a file to share as a link" : "Valilingiga jagatav fail",
+    "Choose a file to share as a link" : "Vali lingiga jagatav fail",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Untitled message" : "Ilma pealkirjata kiri",
     "Expand composer" : "Näita koostamisvaadet laiemana",
     "Close composer" : "Sulge koostamisvaade",
     "Confirm" : "Kinnita",
     "Tag: {name} deleted" : "Silt: {name} on kustutatud",
-    "An error occurred, unable to delete the tag." : "Tekkis viga, silt ei õnnestu kustutada",
+    "An error occurred, unable to delete the tag." : "Tekkis viga, silti ei õnnestu kustutada",
     "The tag will be deleted from all messages." : "See silt saab olema eemaldatud kõikide kirjade juurest.",
     "Plain text" : "Vormindamata tekst",
     "Rich text" : "Vormindatud tekst",
@@ -630,7 +630,12 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "Rong {trainNr}:  {depStation} → {arrStation}",
     "Train from {depStation} to {arrStation}" : "Rong: {depStation} → {arrStation}",
     "Train" : "Rong",
+    "Add flag" : "Lisa tunnus",
+    "Move into folder" : "Tõsta kausta",
+    "Stop" : "Lõpeta",
     "Delete action" : "Kustuta tegevus",
+    "Enter flag" : "Sisesta tunnus",
+    "Stop ends all processing" : "Peatamisel kogu töötlemine lõppeb",
     "Sender" : "Saatja",
     "Recipient" : "Saaja",
     "Create a new mail filter" : "Koosta uus e-posti filter",
@@ -644,14 +649,21 @@ OC.L10N.register(
     "Filter deleted" : "Filter on kustutatud",
     "Could not delete filter" : "Filtri kustutamine on õnnestunud",
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Halda e-kirjade kaost. Filtrid aitavad sul olulist esile tõsta ja müra eemaldada.",
+    "Hang tight while the filters load" : "Palun oota, kuni filtrid saavad laaditud",
     "Filter is active" : "Filter on kasutusel",
     "Filter is not active" : "Filter pole kasutusel",
     "If all the conditions are met, the actions will be performed" : "Kui kõik tingimused vastavad siis, need tegevused käivitatakse",
     "If any of the conditions are met, the actions will be performed" : "Kui mõni tingimus vastab siis, need tegevused käivitatakse",
+    "Help" : "Abiteave",
     "contains" : "sisaldab",
     "matches" : "kattub",
+    "Enter subject" : "Sisesta teema",
+    "Enter sender" : "Sisesta saatja",
+    "Enter recipient" : "Sisesta saaja",
     "is exactly" : "on täpselt",
+    "Conditions" : "Tingimused",
     "Add condition" : "Lisa tingimus",
+    "Actions" : "Tegevused",
     "Add action" : "Lisa tegevus",
     "Priority" : "Olulisus",
     "Enable filter" : "Kasuta filtrit",
@@ -811,24 +823,6 @@ OC.L10N.register(
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
-    "Continue to %s" : "Jätka siia: %s",
-    "Mailvelope is enabled for the current domain!" : "Mailvelope on selle domeeni puhul kasutusel!",
-    "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
-    "Install Mailvelope browser extension" : "Paigalda Mailvelope'i brauserilaiendus",
-    "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!",
-    "Flag" : "Märgi",
-    "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
-    "Operator" : "Operaator",
-    "Delete test" : "Kustuta test",
-    "Update mail filter" : "Uuenda e-posti filtrit",
-    "Filter name" : "Filtri nimi",
-    "If all the conditions are met" : "Kui kõik tingimused on täidetud",
-    "If any of the conditions are met" : "Kui mõni tingimutest on täidetud",
-    "Then perform these actions" : "Seejärel käivita need tegevused",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "Tegevused käivituvad, kui konkreetse testi vastus on tõene. Saadaval on järgnevad tegevused:",
-    "Moves the message into a specified folder." : "Teisaldab kirja etteantud kausta.",
-    "Adds a flag to the message." : "Lisab kirjale märgistuse.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Lõpetab Sieve skripti töö. Peale seda ei töödelda ühtegi järgnevat tingimust.",
-    "Save filter" : "Salvesta filter"
+    "Continue to %s" : "Jätka siia: %s"
 },
 "nplurals=2; plural=(n != 1);");
