@@ -566,6 +566,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} trena {depStation} geltokitik {arrStation} geltokira",
     "Train from {depStation} to {arrStation}" : "Trena {depStation} geltokitik {arrStation} geltokira",
     "Train" : "Trena",
+    "Stop" : "Gelditu",
     "Delete action" : "Ezabatu ekintza",
     "Recipient" : "Hartzailea",
     "Delete filter" : "Ezabatu iragazkia",
@@ -579,10 +580,12 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Kontrolatu zure posta elektronikoaren kaosa. Iragazkiek garrantzitsuena lehenestu eta zaborra ezabatzen laguntzen dizute.",
     "Filter is active" : "Iragazkia gaituta dago",
     "Filter is not active" : "Iragazkia desgaituta dago",
+    "Help" : "Laguntza",
     "contains" : "dauka",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Azpikate bat etortzea. Eremua bat dator emandako balioa barruan badago. Adibidez, \"aireportua\" bat etorriko litzake \"portua\"-rekin.",
     "matches" : "bat dator",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Patroi bat etortzea komodinak erabiliz. «*» sinboloa edozein karaktere (ezer ez barne) kopuru adierazten du. Bestalde, «?» karaktere bakarra adierazten du. Adibidez «*txosten*» «2024ko txostena»-rekin bat etorriko litzateke.",
+    "Actions" : "Ekintzak",
     "Priority" : "Lehentasuna",
     "Enable filter" : "Gaitu iragazkia",
     "Tag" : "Etiketa",
@@ -736,23 +739,6 @@ OC.L10N.register(
     "Redirect" : "Birbideratu",
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
-    "Continue to %s" : "Jarraitu hona: %s",
-    "Mailvelope is enabled for the current domain!" : "Mailvelope gaituta dago uneko domeinurako!",
-    "Looking for a way to encrypt your emails?" : "Zure mezu elektronikoak enkriptatzeko modu bat bilatzen ari zara?",
-    "Install Mailvelope browser extension" : "Instalatu Mailvelope arakatzailearen luzapena",
-    "Enable Mailvelope for the current domain" : "Gaitu Mailvelope uneko domeinurako",
-    "Flag" : "Bandera",
-    "The stop action ends all processing" : "Gelditze-ekintzak prozesua amaitzen du.",
-    "Operator" : "Eragilea",
-    "Delete test" : "Ezabatu proba",
-    "Update mail filter" : "Eguneratu posta iragazkia",
-    "Filter name" : "Iragaziaren izena",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Zure posta-zerbitzarian sartzen diren posta elektronikoei aplikatzen zaizkie probak. Eremu hauek probatzen dira: gaia (posta elektronikoaren gai-lerroa), bidaltzailea eta hartzailea. Honako eragile hauek erabil ditzakezu eremu horietarako baldintzak zehazteko:",
-    "An exact match. The field must be identical to the provided value." : "Bat etortze zehatza. Eremuak emandako balioaren berdina izan behar du.",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "Ekintzak zehaztutako probak egiazkoak direnean abiarazten dira. Honako ekintza hauek daude:",
-    "Moves the message into a specified folder." : "Mezua karpeta zehatz batera eramaten du.",
-    "Adds a flag to the message." : "Bandera bat gehitzen dio mezuari.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Iragazpen scriptaren exekuzioa geldiarazten du. Ekintza honen ondoren ez da iragazki gehiagorik prozesatuko.",
-    "Save filter" : "Gorde iragazkia"
+    "Continue to %s" : "Jarraitu hona: %s"
 },
 "nplurals=2; plural=(n != 1);");
