@@ -474,6 +474,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
     "Train" : "Juna",
+    "Stop" : "Pysäytä",
     "Delete action" : "Poista toiminto",
     "Sender" : "Lähettäjä",
     "Recipient" : "Vastaanottaja",
@@ -489,9 +490,11 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Ota postikaaos hallintaan. Suodattimet auttavat asettamaan asioita tärkeysjärjestykseen ja minimoimaan turhuudet.",
     "Filter is active" : "Suodatin on aktiivinen",
     "Filter is not active" : "Suodatin ei ole aktiivinen",
+    "Help" : "Ohje",
     "contains" : "sisältää",
     "matches" : "täsmää",
     "Add condition" : "Lisää ehto",
+    "Actions" : "Toiminnot",
     "Add action" : "Lisää toiminto",
     "Priority" : "Tärkeys",
     "Enable filter" : "Käytä suodatinta",
@@ -606,17 +609,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
-    "Continue to %s" : "Jatka sivulle %s",
-    "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
-    "Install Mailvelope browser extension" : "Asenna Mailvelope-selainlaajennus",
-    "Flag" : "Lippu",
-    "Operator" : "Operaattori",
-    "Update mail filter" : "Päivitä viestisuodatin",
-    "Filter name" : "Nimisuodatin",
-    "If all the conditions are met" : "jos kaikki ehdot ovat tosia",
-    "If any of the conditions are met" : "jos yksi ehdoista on tosi",
-    "Then perform these actions" : "Sitten suorita nämä toiminnot",
-    "Moves the message into a specified folder." : "Siirtää viestin haluttuun kansioon.",
-    "Save filter" : "Tallenna suodatin"
+    "Continue to %s" : "Jatka sivulle %s"
 },
 "nplurals=2; plural=(n != 1);");
