@@ -283,7 +283,9 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
     "Train" : "Vlak",
     "Recipient" : "Primatelj",
+    "Help" : "Pomoć",
     "matches" : "podudara se",
+    "Actions" : "Radnje",
     "Priority" : "Prioritet",
     "Tag" : "Oznaka",
     "delete" : "izbriši",
