@@ -52,7 +52,9 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Etiquettas",
     "Custom" : "Personalisate",
+    "Help" : "Adjuta",
     "matches" : "corresponde",
+    "Actions" : "Actiones",
     "Priority" : "Prioritate",
     "delete" : "deler",
     "Edit" : "Modificar",
