@@ -145,7 +145,7 @@ OC.L10N.register(
     "Message {id} could not be found" : "Пораката {id} не е пронајдена",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
     "Turn off formatting" : "Исклучи форматирање",
-    "Turn off and remove formatting" : "Исклучи и острани форматирање",
+    "Turn off and remove formatting" : "Исклучи и отстрани форматирање",
     "Keep formatting" : "Зачувај го форматирањето",
     "From" : "Од",
     "Select account" : "Избете сметка",
@@ -244,7 +244,7 @@ OC.L10N.register(
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
     "More options" : "Повеќе опции ",
-    "Could not remove internal address {sender}" : "Неможе да се острани внатрешната адреса {sender}",
+    "Could not remove internal address {sender}" : "Неможе да се отстрани внатрешната адреса {sender}",
     "Could not add internal address {address}" : "Неможе да се додаде внатрешната адреса {address}",
     "individual" : "индивидуално",
     "domain" : "домен",
