@@ -270,7 +270,9 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
     "Train" : "Trenu",
     "New filter" : "Filtru nou",
+    "Help" : "Agiudu",
     "matches" : "currispondèntzias",
+    "Actions" : "Atziones",
     "Priority" : "Prioridade",
     "delete" : "cantzella",
     "Edit" : "Modìfica",
