@@ -106,7 +106,9 @@ OC.L10N.register(
     "Tag already exists" : "Etiketa ekziston",
     "Add tag" : "Shto etiketim",
     "Recipient" : "Marrës",
+    "Help" : "Ndihmë",
     "matches" : "përputhje",
+    "Actions" : "Veprimet",
     "Priority" : "Përparësi",
     "delete" : "fshi",
     "Edit" : "Përpuno",
