@@ -232,8 +232,10 @@ OC.L10N.register(
     "Train" : "Tàu hỏa",
     "Recipient" : "Người nhận",
     "Delete filter" : "Xóa bộ lọc ",
+    "Help" : "Trợ giúp",
     "contains" : "chứa",
     "matches" : "so sánh",
+    "Actions" : "Hành động",
     "delete" : "xóa",
     "Edit" : "Chỉnh sửa",
     "Mail app" : "Ứng dụng thư",
