@@ -11,7 +11,6 @@ namespace OCA\Mail\Service;
 
 use OCA\Mail\Account;
 use OCA\Mail\Contracts\IMailManager;
-use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Db\LocalMessage;
 use OCA\Mail\Db\LocalMessageMapper;
 use OCA\Mail\Db\Recipient;
@@ -29,8 +28,7 @@ use Psr\Log\LoggerInterface;
 use Throwable;
 
 class OutboxService {
-	/** @var IMailTransmission */
-	private $transmission;
+
 
 	/** @var LocalMessageMapper */
 	private $mapper;
@@ -57,7 +55,6 @@ class OutboxService {
 	private $logger;
 
 	public function __construct(
-		IMailTransmission $transmission,
 		LocalMessageMapper $mapper,
 		AttachmentService $attachmentService,
 		IEventDispatcher $eventDispatcher,
@@ -68,7 +65,6 @@ class OutboxService {
 		LoggerInterface $logger,
 		private Chain $sendChain,
 	) {
-		$this->transmission = $transmission;
 		$this->mapper = $mapper;
 		$this->attachmentService = $attachmentService;
 		$this->eventDispatcher = $eventDispatcher;
